@@ -54,7 +54,9 @@ class CreateBranch:
             ).lower(),
         )
 
-        default_parent_branch_name = self._git.current_branch_name()
+        default_parent_branch_name = self._config.user.get(
+            "default_parent_branch", self._git.current_branch_name()
+        )
 
         parent_branch_name = prompt_utils.ask_questions_input(
             "Inserisci branch iniziale: ", default_parent_branch_name
