@@ -2,22 +2,14 @@
 import sys
 import requests
 
-from suite_py.lib.config import Config
-from suite_py.lib.singleton import Singleton
 from suite_py.lib.handler import git_handler as git
-from suite_py.lib.logger import Logger
-
-config = Config()
-logger = Logger()
+from suite_py.lib import logger
 
 
-class CaptainHook(metaclass=Singleton):
-    _baseurl = None
-    _timeout = None
-
-    def __init__(self):
-        self._baseurl = config.load()["user"]["captainhook_url"]
-        self._timeout = config.load()["user"]["captainhook_timeout"]
+class CaptainHook:
+    def __init__(self, config):
+        self._baseurl = config.user["captainhook_url"]
+        self._timeout = config.user["captainhook_timeout"]
 
     def lock_project(self, project, env):
         data = {
@@ -49,11 +41,7 @@ class CaptainHook(metaclass=Singleton):
         return self.send_get_request("/users/all")
 
     def rollback(self, project, version):
-        data = {
-            "project": project,
-            "user": git.get_username(),
-            "version": version,
-        }
+        data = {"project": project, "user": git.get_username(), "version": version}
         return self.send_post_request("/projects/rollback", data)
 
     def send_post_request(self, endpoint, data):
